#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit test

%define		crates_ver	41.0.4

Summary:	Crypthography library for Python 3
Summary(pl.UTF-8):	Biblioteka Cryptography dla Pythona 3
Name:		python3-cryptography
Version:	41.0.4
Release:	2
License:	Apache v2.0 or BSD
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/cryptography/
Source0:	https://files.pythonhosted.org/packages/source/c/cryptography/cryptography-%{version}.tar.gz
# Source0-md5:	e53b22d4baae5430e881f2f516effa67
#Source1Download: https://pypi.org/simple/cryptography_vectors/
Source1:	https://files.pythonhosted.org/packages/source/c/cryptography-vectors/cryptography_vectors-%{version}.tar.gz
# Source1-md5:	baa05bd96d91129bb8123881fca0129d
# cd cryptography-%{version}/src/rust
# cargo vendor
# tar cJf python3-cryptography-crates-%{version}.tar.xz vendor Cargo.lock
Source2:	%{name}-crates-%{crates_ver}.tar.xz
# Source2-md5:	940f9f8bc4bbdd7d1fe081e38cbf90d3
URL:		https://cryptography.io/
BuildRequires:	openssl-devel >= 1.1.1d
BuildRequires:	python3-cffi >= 1.12
BuildRequires:	python3-devel >= 1:3.7
BuildRequires:	python3-setuptools >= 1:61.0.0
BuildRequires:	python3-setuptools_rust >= 0.11.4
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpm-pythonprov >= 5.4.15-48
BuildRequires:	rpmbuild(macros) >= 2.004
BuildRequires:	rust >= 1.56.0
%if %{with tests}
BuildRequires:	python3-hypothesis >= 1.11.4
BuildRequires:	python3-pretend
BuildRequires:	python3-pytest >= 6.2.0
BuildRequires:	python3-pytest-benchmark
%endif
%if %{with doc}
# TODO: bump to 1.1.1 / 5.3.0 resp.
BuildRequires:	python3-sphinx_rtd_theme >= 1.0.0
BuildRequires:	sphinx-pdg-3 >= 4.5.0
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
%endif
Requires:	openssl >= 1.1.1d
ExclusiveArch:	%{rust_arches}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
cryptography is a package which provides cryptographic recipes and
primitives to Python developers. Our goal is for it to be your
"cryptographic standard library". It supports Python 3.6+ and
PyPy3 7.2+.

cryptography includes both high level recipes and low level interfaces
to common cryptographic algorithms such as symmetric ciphers, message
digests, and key derivation functions.

%description -l pl.UTF-8
cryptography to pakiet zaprojektowany w celu udostępnienia funkcji i
obiektów kryptograficznych programistom Pythona. Celem jest
dostarczenie "standardowej biblioteki kryptograficznej". Obsługuje
Pythona 3.6+ oraz PyPy 7.2+.

cryptography zawiera zarówno funkcje wysokopoziomowe, jak i
niskopoziomowe interfejsy do popularnych algorytmów kryptograficznych,
takich jak szyfry symetryczne, skróty wiadomości czy funkcje
wyprowadzające klucze.

%package apidocs
Summary:	API documentation for cryptography module
Summary(pl.UTF-8):	Dokumentacja API modułu cryptography
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for cryptography module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu cryptography.

%prep
%setup -q -n cryptography-%{version} %{?with_tests:-a1}

%if %{with tests}
%{__mv} cryptography_vectors-%{version}/cryptography_vectors .
%endif

cd src/rust
tar xf %{SOURCE2}
# use our offline registry
export CARGO_HOME="$(pwd)/.cargo"

mkdir -p "$CARGO_HOME"
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'

[source.vendored-sources]
directory = '$PWD/vendor'
EOF

%build
export CARGO_HOME="$(pwd)/src/rust/.cargo"
export CARGO_OFFLINE=true
export RUSTFLAGS="%{rpmrustflags}"
export CARGO_TERM_VERBOSE=true
%ifarch x32
export CARGO_BUILD_TARGET=x86_64-unknown-linux-gnux32
export PKG_CONFIG_ALLOW_CROSS=1
%endif

export CFLAGS="%{rpmcflags}"

%py3_build

%if %{with tests}
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
PYTEST_PLUGINS="pytest_benchmark.plugin" \
PYTHONPATH=$(echo $(pwd)/build-3/lib.*) \
%{__python3} -m pytest tests
%endif

%if %{with doc}
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

export CARGO_HOME="$(pwd)/src/rust/.cargo"
export CARGO_OFFLINE=true
export RUSTFLAGS="%{rpmrustflags}"
export CARGO_TERM_VERBOSE=true
%ifarch x32
export CARGO_BUILD_TARGET=x86_64-unknown-linux-gnux32
export PKG_CONFIG_ALLOW_CROSS=1
%endif

%py3_install

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGELOG.rst CONTRIBUTING.rst LICENSE LICENSE.APACHE LICENSE.BSD README.rst
%dir %{py3_sitedir}/cryptography
%{py3_sitedir}/cryptography/*.py
%{py3_sitedir}/cryptography/py.typed
%{py3_sitedir}/cryptography/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat
%{py3_sitedir}/cryptography/hazmat/*.py
%{py3_sitedir}/cryptography/hazmat/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/backends
%{py3_sitedir}/cryptography/hazmat/backends/*.py
%{py3_sitedir}/cryptography/hazmat/backends/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/backends/openssl
%{py3_sitedir}/cryptography/hazmat/backends/openssl/*.py
%{py3_sitedir}/cryptography/hazmat/backends/openssl/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/bindings
%{py3_sitedir}/cryptography/hazmat/bindings/*.py
%{py3_sitedir}/cryptography/hazmat/bindings/__pycache__
%attr(755,root,root) %{py3_sitedir}/cryptography/hazmat/bindings/_*.so
%dir %{py3_sitedir}/cryptography/hazmat/bindings/_rust
%{py3_sitedir}/cryptography/hazmat/bindings/_rust/*.pyi
%dir %{py3_sitedir}/cryptography/hazmat/bindings/_rust/openssl
%{py3_sitedir}/cryptography/hazmat/bindings/_rust/openssl/*.pyi
%dir %{py3_sitedir}/cryptography/hazmat/bindings/openssl
%{py3_sitedir}/cryptography/hazmat/bindings/openssl/*.py
%{py3_sitedir}/cryptography/hazmat/bindings/openssl/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives
%{py3_sitedir}/cryptography/hazmat/primitives/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/asymmetric
%{py3_sitedir}/cryptography/hazmat/primitives/asymmetric/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/asymmetric/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/ciphers
%{py3_sitedir}/cryptography/hazmat/primitives/ciphers/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/ciphers/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/kdf
%{py3_sitedir}/cryptography/hazmat/primitives/kdf/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/kdf/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/serialization
%{py3_sitedir}/cryptography/hazmat/primitives/serialization/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/serialization/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/twofactor
%{py3_sitedir}/cryptography/hazmat/primitives/twofactor/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/twofactor/__pycache__
%dir %{py3_sitedir}/cryptography/x509
%{py3_sitedir}/cryptography/x509/*.py
%{py3_sitedir}/cryptography/x509/__pycache__
%{py3_sitedir}/cryptography-%{version}-py*.egg-info

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_downloads,_static,development,hazmat,x509,*.html,*.js}
%endif
%changelog
* Sat Oct 07 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-cryptography.git;a=log;h=master

* Sat Oct 07 2023 Jakub Bogusz <qboosh@pld-linux.org> 30e9953
- x32 build fix; release 2

* Fri Oct 06 2023 Jakub Bogusz <qboosh@pld-linux.org> f36af98
- updated dependencies, revendored crates with proper Cargo.lock (and filtered to linux)

* Thu Oct 05 2023 Arkadiusz Miśkiewicz <arekm@maven.pl> e8e4527
- Up to 41.0.4

* Wed Dec 21 2022 Arkadiusz Miśkiewicz <arekm@maven.pl> ce79e83
- Up to 38.0.4

* Tue Nov 22 2022 Jakub Bogusz <qboosh@pld-linux.org> 96ce776
- updated to 38.0.3

* Sun Sep 11 2022 Jakub Bogusz <qboosh@pld-linux.org> bbccd1e
- updated tests dependencies

* Sun Sep 04 2022 Jakub Bogusz <qboosh@pld-linux.org> c6d76ef
- updated to 37.0.4

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 1f32452
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 0385da0
- rebuild with python 3.10

* Wed Dec 15 2021 Jakub Bogusz <qboosh@pld-linux.org> e9e6242
- setuptools epoch

* Sun Oct 10 2021 Jan Palus <atler@pld-linux.org> d689083
- rel 1

* Sun Oct 10 2021 Jan Palus <atler@pld-linux.org> c1d4b28
- BR: python3-setuptools_rust

* Sun Oct 10 2021 Jan Palus <atler@pld-linux.org> 7791f4c
- vendorize rust extension

* Sat Oct 09 2021 Jan Palus <atler@pld-linux.org> 7a9c1d5
- updated %files

* Mon Oct 04 2021 Jan Rękorajski <baggins@pld-linux.org> 59f13c5
- up to 35.0.0, requires rust and setuptools_rust

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 3ff5673
- unconditional noarch subpackages

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 54c5254
- release 3 (by relup.sh)

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> ffd9000
- release 2 (by relup.sh)

* Sun Jan 17 2021 Jakub Bogusz <qboosh@pld-linux.org> 0f792d5
- updated to 3.3.1

* Sun Jun 07 2020 Jakub Bogusz <qboosh@pld-linux.org> 29f64be
- updated to 2.9.2

